aboutsummaryrefslogtreecommitdiff
path: root/ef-night-theme.el
diff options
context:
space:
mode:
authorProtesilaos Stavrou <info@protesilaos.com>2022-09-07 06:19:10 +0300
committerProtesilaos Stavrou <info@protesilaos.com>2022-09-07 06:19:10 +0300
commitc11d7b767134be9a7b91453e2792fe009c7529b7 (patch)
tree85207f0378436a6cbec1c52087acdca500418e88 /ef-night-theme.el
parent0416ea8554a78e8ae352fb314a336672b048d41c (diff)
Make theme one-line descriptions more descriptive
Diffstat (limited to 'ef-night-theme.el')
-rw-r--r--ef-night-theme.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/ef-night-theme.el b/ef-night-theme.el
index b311a72..bcf2845 100644
--- a/ef-night-theme.el
+++ b/ef-night-theme.el
@@ -1,4 +1,4 @@
;;; ef-night-theme.el --- Legible dark theme with cool colors -*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
@@ -37,7 +37,7 @@
(eval-and-compile
(require 'ef-themes)
- (deftheme ef-night "Legible dark theme with cool colors.")
+ (deftheme ef-night "Legible dark theme with mostly green, blue, purple colors.")
(defconst ef-night-palette
'(;; Basic tones
@@ -1,4 +1,4 @@
-;;; ef-night-theme.el --- Legible dark theme with cool colors -*- lexical-binding:t -*-
+;;; ef-night-theme.el --- Legible dark theme with mostly green, blue, purple colors -*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.